# Verify the kernel version to run depmod

MYMODVER=2.6.24.5-smp
MYKERNEL=`uname -r`

if [ "$MYKERNEL" = "$MYMODVER" ]; then
  if [ -x sbin/depmod ]; then
    chroot . /sbin/depmod -ae 1> /dev/null 2> /dev/null
  fi
fi
