# Only run depmod on matching running kernel
# Slackware will run depmod anyway on reboot:

MYMODVER=2.6.21.5-smp
MYKERNEL=`uname -r`

if [ "$MYKERNEL" = "$MYMODVER" ]; then
  if [ -x sbin/depmod ]; then
    chroot . /sbin/depmod -a 1> /dev/null 2> /dev/null
  fi
fi
